@@ -32,8 +32,6 @@ import (
 
 	"github.com/openshift/origin/test/extended/networking"
 	exutil "github.com/openshift/origin/test/extended/util"
-
-	operatorv1 "github.com/openshift/api/operator/v1"
 )
 
 const waitForPrometheusStartSeconds = 240
@@ -65,11 +63,11 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 			execPodName := e2e.CreateExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", func(pod *v1.Pod) { pod.Spec.Containers[0].Image = "centos:7" })
 			defer func() { oc.AdminKubeClient().CoreV1().Pods(ns).Delete(execPodName, metav1.NewDeleteOptions(1)) }()
 
-			tests := map[string][]metricTest{
+			tests := map[string]bool{
 				// should have successfully sent at least once to remote
-				`metricsclient_request_send{client="federate_to",job="telemeter-client",status_code="200"}`: {metricTest{greaterThanEqual: true, value: 1}},
+				`metricsclient_request_send{client="federate_to",job="telemeter-client",status_code="200"} >= 1`: true,
 				// should have scraped some metrics from prometheus
-				`federate_samples{job="telemeter-client"}`: {metricTest{greaterThanEqual: true, value: 10}},
+				`federate_samples{job="telemeter-client"} >= 10`: true,
 			}
 			runQueries(tests, oc, ns, execPodName, url, bearerToken)
 
@@ -168,11 +166,9 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 			execPodName := e2e.CreateExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", func(pod *v1.Pod) { pod.Spec.Containers[0].Image = "centos:7" })
 			defer func() { oc.AdminKubeClient().CoreV1().Pods(ns).Delete(execPodName, metav1.NewDeleteOptions(1)) }()
 
-			tests := map[string][]metricTest{
-				// should have a constantly firing watchdog alert
-				`ALERTS{alertstate="firing",alertname="Watchdog"}`: {metricTest{greaterThanEqual: true, value: 1}},
-				// should be only one watchdog alert (this is a workaround as metricTest doesn't offer equality operator)
-				`ALERTS{alertstate="firing",alertname="Watchdog",severity="none"}`: {metricTest{greaterThanEqual: false, value: 2}},
+			tests := map[string]bool{
+				// should have constantly firing a watchdog alert
+				`ALERTS{alertstate="firing",alertname="Watchdog",severity="none"} == 1`: true,
 			}
 			runQueries(tests, oc, ns, execPodName, url, bearerToken)
 
@@ -184,9 +180,8 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 			execPodName := e2e.CreateExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", func(pod *v1.Pod) { pod.Spec.Containers[0].Image = "centos:7" })
 			defer func() { oc.AdminKubeClient().CoreV1().Pods(ns).Delete(execPodName, metav1.NewDeleteOptions(1)) }()
 
-			tests := map[string][]metricTest{
-				// should have constantly firing a watchdog alert
-				`container_cpu_usage_seconds_total{id!~"/kubepods.slice/.*"}`: {metricTest{greaterThanEqual: true, value: 1}},
+			tests := map[string]bool{
+				`container_cpu_usage_seconds_total{id!~"/kubepods.slice/.*"} >= 1`: true,
 			}
 			runQueries(tests, oc, ns, execPodName, url, bearerToken)
 		})
@@ -197,14 +192,14 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 				execPodName := e2e.CreateExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", func(pod *v1.Pod) { pod.Spec.Containers[0].Image = "centos:7" })
 				defer func() { oc.AdminKubeClient().CoreV1().Pods(ns).Delete(execPodName, metav1.NewDeleteOptions(1)) }()
 
-				tests := map[string][]metricTest{
+				tests := map[string]bool{
 					//something
-					`openshift_sdn_ovs_flows`: {metricTest{greaterThanEqual: true, value: 1}},
+					`openshift_sdn_ovs_flows >= 1`: true,
 				}
 				runQueries(tests, oc, ns, execPodName, url, bearerToken)
 			})
 		})
-		g.It("should report less than two alerts in firing or pending state", func() {
+		g.It("shouldn't report any alerts in firing state apart from Watchdog and AlertmanagerReceiversNotConfigured", func() {
 			if len(os.Getenv("TEST_UNSUPPORTED_ALLOW_VERSION_SKEW")) > 0 {
 				e2e.Skipf("Test is disabled to allow cluster components to have different versions, and skewed versions trigger multiple other alerts")
 			}
@@ -213,10 +208,9 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 			execPodName := e2e.CreateExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", func(pod *v1.Pod) { pod.Spec.Containers[0].Image = "centos:7" })
 			defer func() { oc.AdminKubeClient().CoreV1().Pods(ns).Delete(execPodName, metav1.NewDeleteOptions(1)) }()
 
-			tests := map[string][]metricTest{
-				// should be checking there is no more than 1 alerts firing.
-				// Checking for specific alert is done in "should have a Watchdog alert in firing state".
-				`sum(ALERTS{alertstate="firing"})`: {metricTest{greaterThanEqual: false, value: 2}},
+			tests := map[string]bool{
+				// Checking Watchdog alert state is done in "should have a Watchdog alert in firing state".
+				`ALERTS{alertname!~"Watchdog|AlertmanagerReceiversNotConfigured",alertstate="firing"} >= 1`: false,
 			}
 			runQueries(tests, oc, ns, execPodName, url, bearerToken)
 		})
@@ -227,37 +221,6 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 			execPodName := e2e.CreateExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", func(pod *v1.Pod) { pod.Spec.Containers[0].Image = "centos:7" })
 			defer func() { oc.AdminKubeClient().CoreV1().Pods(ns).Delete(execPodName, metav1.NewDeleteOptions(1)) }()
 
-			g.By("creating a non-default ingresscontroller")
-			replicas := int32(1)
-			ingress := &operatorv1.IngressController{
-				ObjectMeta: metav1.ObjectMeta{
-					Namespace: "openshift-ingress-operator",
-					Name:      "prometheus",
-				},
-				Spec: operatorv1.IngressControllerSpec{
-					Domain:   "prometheus.e2e.openshift.example.com",
-					Replicas: &replicas,
-					EndpointPublishingStrategy: &operatorv1.EndpointPublishingStrategy{
-						Type: operatorv1.PrivateStrategyType,
-					},
-					RouteSelector: &metav1.LabelSelector{
-						MatchLabels: map[string]string{
-							"e2e-test": ns,
-						},
-					},
-				},
-			}
-			_, err := oc.AdminOperatorClient().OperatorV1().IngressControllers(ingress.Namespace).Create(ingress)
-			o.Expect(err).NotTo(o.HaveOccurred())
-
-			defer func() {
-				if err := oc.AdminOperatorClient().OperatorV1().IngressControllers(ingress.Namespace).Delete(ingress.Name, metav1.NewDeleteOptions(1)); err != nil {
-					e2e.Logf("WARNING: failed to delete ingresscontroller '%s/%s' created during test cleanup: %v", ingress.Namespace, ingress.Name, err)
-				} else {
-					e2e.Logf("deleted test ingresscontroller '%s/%s'", ingress.Namespace, ingress.Name)
-				}
-			}()
-
 			var lastErrs []error
 			o.Expect(wait.PollImmediate(10*time.Second, 4*time.Minute, func() (bool, error) {
 				contents, err := getBearerTokenURLViaPod(ns, execPodName, fmt.Sprintf("%s/api/v1/targets", url), bearerToken)
@@ -271,7 +234,6 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 				lastErrs = all(
 					// Is there a good way to discover the name and thereby avoid leaking the naming algorithm?
 					targets.Expect(labels{"job": "router-internal-default"}, "up", "^https://.*/metrics$"),
-					targets.Expect(labels{"job": "router-internal-prometheus"}, "up", "^https://.*/metrics$"),
 				)
 				if len(lastErrs) > 0 {
 					e2e.Logf("missing some targets: %v", lastErrs)
@@ -281,11 +243,9 @@ var _ = g.Describe("[Feature:Prometheus][Conformance] Prometheus", func() {
 			})).NotTo(o.HaveOccurred(), "ingress router cannot report metrics to monitoring system")
 
 			g.By("verifying standard metrics keys")
-			queries := map[string][]metricTest{
-				`template_router_reload_seconds_count{job="router-internal-default"}`:    {metricTest{greaterThanEqual: true, value: 1}},
-				`haproxy_server_up{job="router-internal-default"}`:                       {metricTest{greaterThanEqual: true, value: 1}},
-				`template_router_reload_seconds_count{job="router-internal-prometheus"}`: {metricTest{greaterThanEqual: true, value: 1}},
-				`haproxy_server_up{job="router-internal-prometheus"}`:                    {metricTest{greaterThanEqual: true, value: 1}},
+			queries := map[string]bool{
+				`template_router_reload_seconds_count{job="router-internal-default"} >= 1`: true,
+				`haproxy_server_up{job="router-internal-default"} >= 1`:                    true,
 			}
 			runQueries(queries, oc, ns, execPodName, url, bearerToken)
 		})
